@@ -65,8 +65,8 @@ def m2m_lookup(request):
                     if obj_id:
                         try:
                             obj = model.objects.get(pk=obj_id)
-                            data.append({"value":obj.id,"label":get_label(obj)})
-                        except:
+                            data.append({"value":obj.pk,"label":get_label(obj)})
+                        except obj.DoesNotExist:
                             data.append({"value":obj_id,"label":_("?")})
             return HttpResponse(simplejson.dumps(data), mimetype='application/javascript')
     data = [{"value":None,"label":""}]
